@@ -4,6 +4,8 @@ describe 'vitrage::db::sync' do
 
   shared_examples_for 'vitrage-dbsync' do
 
+    it { is_expected.to contain_class('vitrage::deps') }
+
     it 'runs vitrage-manage db sync' do
       is_expected.to contain_exec('vitrage-db-sync').with(
         :command     => 'vitrage-dbsync ',
@@ -17,6 +19,7 @@ describe 'vitrage::db::sync' do
                          'Anchor[vitrage::config::end]',
                          'Anchor[vitrage::dbsync::begin]'],
         :notify      => 'Anchor[vitrage::dbsync::end]',
+        :tag         => 'openstack-db',
       )
     end
 
@@ -40,6 +43,7 @@ describe 'vitrage::db::sync' do
                          'Anchor[vitrage::config::end]',
                          'Anchor[vitrage::dbsync::begin]'],
           :notify      => 'Anchor[vitrage::dbsync::end]',
+          :tag         => 'openstack-db',
         )
       }
     end
